API docs for “spamfighter.plugin.INamedPlugin”

# Class s.p.INamedPlugin(Interface):

Part of spamfighter.plugin View Source View In Hierarchy

Known subclasses: spamfighter.plugin.IDefaultDomainProvider, spamfighter.plugin.IPartnerAuthorizerProvider, spamfighter.test.plugins.ITestPlugin1, spamfighter.test.plugins.ITestPlugin2, spamfighter.test.plugins.ITestPlugin3

Базовый интерфейс плагинов: плагин, который имеет имя.

Method | name | Получить имя плагина.

def name(): (source)
Получить имя плагина.

Returns | имя плагина (type: `str` )